@@ -26,7 +26,7 @@ use strict;
 
 use vars qw( $MODE_DUMMY $MODE_INTERNAL $MODE_EXTERNAL $MODE_UPDATE );
 use vars qw( $TEST_DUMMY $TEST_EXACTLY $TEST_BY_COUNTING $TEST_GREATER_THAN $TEST_RANGE );
-use vars qw( $iTest $oSearch );
+use vars qw( $iTest $oSearch $sEngine );
 
 require Exporter;
 use vars qw( @EXPORT @EXPORT_OK @ISA );
@@ -34,7 +34,7 @@ use vars qw( @EXPORT @EXPORT_OK @ISA );
               no_test not_working not_working_with_tests not_working_and_abandoned
               $MODE_DUMMY $MODE_INTERNAL $MODE_EXTERNAL $MODE_UPDATE
               $TEST_DUMMY $TEST_EXACTLY $TEST_BY_COUNTING $TEST_GREATER_THAN $TEST_RANGE
-              new_engine run_test run_gui_test
+              new_engine run_test run_gui_test skip_test
             );
 @EXPORT_OK = qw( );
 @ISA = qw( Exporter );
@@ -45,16 +45,21 @@ use File::Path;
 
 use vars qw( $VERSION $bogus_query );
 
-$VERSION = '2.12';
+$VERSION = '2.16';
 $bogus_query = "Bogus" . $$ . "NoSuchWord" . time;
 
 ($MODE_DUMMY, $MODE_INTERNAL, $MODE_EXTERNAL, $MODE_UPDATE) = qw(dummy internal external update);
 ($TEST_DUMMY, $TEST_EXACTLY, $TEST_BY_COUNTING, $TEST_GREATER_THAN, $TEST_RANGE) = (1..10);
 
 # At the time this module is loaded, try to find a working WebSearch:
-my @as = split(/\s/, `WebSearch --VERSION`);
+my @as = split(/\s/, eval{`WebSearch --VERSION`});
 my $websearch = shift @as;
+# Try local directory, in case . is not in the path:
+@as = split(/\s/, eval{`./WebSearch --VERSION`});
+$websearch ||= shift @as;
+$websearch ||= 'not in the path';
 undef $websearch unless $websearch =~ m/WebSearch/;
+# print STDERR "in WWW::Search::Test, websearch is $websearch\n";
 
 =head2 new
 
@@ -398,7 +403,7 @@ sub not_working_with_tests
   return if (!$self->relevant_test($engine));
   print <<"KNOWNFAILURE";
   trial none ($engine)
-  Test cases for this search engine are known to fail.  
+  Test cases for this search engine are known to fail.
   You are encouraged to investigate the problem and email its maintainer,
   $maint.
 KNOWNFAILURE
@@ -419,12 +424,12 @@ sub not_working_and_abandonded
   return if (!$self->relevant_test($engine));
   print <<"ADOPT";
   trial none ($engine)
-  This search engine is known to be non-functional.  
-  You are encouraged to adopt it from its last known maintainer, 
+  This search engine is known to be non-functional.
+  You are encouraged to adopt it from its last known maintainer,
   $maint.
 ADOPT
   } # not_working_and_abandonded
-        
+
 =head2 reset_error_count
 
 Reset the counter of errors to zero.
@@ -515,7 +520,8 @@ to be used for all subsequent calls to run_test and run_gui_test (see below).
 sub new_engine
   {
   $iTest++;
-  $oSearch = new WWW::Search(shift);
+  $sEngine = shift;
+  $oSearch = new WWW::Search($sEngine);
   print ref($oSearch) ? '' : 'not ';
   print "ok $iTest\n";
   } # new_engine
@@ -547,7 +553,9 @@ sub run_gui_test
 
 sub run_our_test
   {
-  my ($sType, $sQuery, $iMin, $iMax, $iDebug) = @_;
+  my ($sType, $sQuery, $iMin, $iMax, $iDebug, $iPrintResults) = @_;
+  $iDebug ||= 0;
+  $iPrintResults ||= 0;
   carp ' --- min/max values out of order?' if defined($iMin) && defined($iMax) && ($iMax < $iMin);
   my $sExpect;
   if (! defined($iMax))
@@ -563,17 +571,27 @@ sub run_our_test
     $sExpect = "$iMin..$iMax";
     }
   $iMin ||= 0;
-  if (defined $iMax)
+  if ($iMin == $iMax)
     {
-    $oSearch->maximum_to_retrieve($iMax+1);
+    # The caller expects an exact result set.  Do not limit how many
+    # results are returned.
+    $oSearch->maximum_to_retrieve(99999);
     }
   else
     {
-    $oSearch->maximum_to_retrieve($iMin + 1);
-    $iMax = 999999;
+    if (defined $iMax)
+      {
+      $oSearch->maximum_to_retrieve($iMax + 1);
+      }
+    else
+      {
+      $oSearch->maximum_to_retrieve($iMin + 1);
+      $iMax = 999999;
+      }
     }
   $iTest++;
   $sQuery = WWW::Search::escape_query($sQuery);
+  # print STDERR " + in WWW::Search::Test::run_our_test, iDebug = $iDebug\n";
   if ($sType eq 'gui')
     {
     $oSearch->gui_query($sQuery,
@@ -587,15 +605,34 @@ sub run_our_test
                           );
     }
   my @aoResults = $oSearch->results();
+  if ($iPrintResults)
+    {
+    $, = "\n";
+    print map { $_->url .' == '. $_->description } @aoResults;
+    print "\n";
+    } # if
   my $iResults = scalar(@aoResults);
   if (($iResults < $iMin) || ($iMax < $iResults))
     {
-    print STDERR " --- got $iResults results for $sType query '$sQuery', but expected $sExpect\n";
+    print STDERR " --- got $iResults results for $sType $sEngine query '$sQuery', but expected $sExpect\n";
     print STDOUT 'not ';
     } # if
   print STDOUT "ok $iTest\n";
   } # run_test
 
+=head2 skip_test
+
+You can call this function instead of run_test() or run_gui_test()
+if the current test must be skipped for any reason.
+
+=cut
+
+sub skip_test
+  {
+  $iTest++;
+  print STDOUT "skip $iTest\n";
+  } # skip_test
+
 1;
 
 __END__
